charms.reactive.endpoints
=========================

.. rubric:: Summary

This is the transitional location of the new `Endpoint <#charms.reactive.endpoints.Endpoint>`_
base for writing interface layers.  Eventually, this should be moved in to `charms.reactive.relations`_.

.. automembersummary::
    :nosignatures:

    ~charms.reactive.endpoints

.. rubric:: Reference

.. automodule:: charms.reactive.endpoints
    :members:
    :ignore-module-all:
    :undoc-members:
    :show-inheritance:


charms.reactive.relations
=========================

.. rubric:: Summary

This is the older API for interface layers that are based on
:class:`~charms.reactive.relations.RelationBase`.  It is recommended that you
try using :class:`~charms.reactive.endpoints.Endpoint` instead.

.. automembersummary::
    :nosignatures:

    ~charms.reactive.relations

.. rubric:: Reference

.. automodule:: charms.reactive.relations
    :members:
    :undoc-members:
    :show-inheritance:
